# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v6___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanCampaignKeyword(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    keyword_plan_campaign: typing___Text = ...
    id: builtin___int = ...
    text: typing___Text = ...
    match_type: google___ads___googleads___v6___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue = ...
    negative: builtin___bool = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        keyword_plan_campaign: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        text: typing___Optional[typing___Text] = None,
        match_type: typing___Optional[
            google___ads___googleads___v6___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue
        ] = None,
        negative: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "_negative",
            b"_negative",
            "_text",
            b"_text",
            "id",
            b"id",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "negative",
            b"negative",
            "text",
            b"text",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "_negative",
            b"_negative",
            "_text",
            b"_text",
            "id",
            b"id",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "match_type",
            b"match_type",
            "negative",
            b"negative",
            "resource_name",
            b"resource_name",
            "text",
            b"text",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_keyword_plan_campaign", b"_keyword_plan_campaign"
        ],
    ) -> typing_extensions___Literal["keyword_plan_campaign"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_negative", b"_negative"]
    ) -> typing_extensions___Literal["negative"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_text", b"_text"]
    ) -> typing_extensions___Literal["text"]: ...

type___KeywordPlanCampaignKeyword = KeywordPlanCampaignKeyword



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdErrorValue = typing___NewType("AdErrorValue", builtin___int)
    type___AdErrorValue = AdErrorValue
    AdError: _AdError
    class _AdError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdErrorEnum.AdErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdErrorEnum.AdErrorValue, 0)
        UNKNOWN = typing___cast(AdErrorEnum.AdErrorValue, 1)
        AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE = typing___cast(
            AdErrorEnum.AdErrorValue, 2
        )
        APPROXIMATELY_TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 3)
        APPROXIMATELY_TOO_SHORT = typing___cast(AdErrorEnum.AdErrorValue, 4)
        BAD_SNIPPET = typing___cast(AdErrorEnum.AdErrorValue, 5)
        CANNOT_MODIFY_AD = typing___cast(AdErrorEnum.AdErrorValue, 6)
        CANNOT_SET_BUSINESS_NAME_IF_URL_SET = typing___cast(AdErrorEnum.AdErrorValue, 7)
        CANNOT_SET_FIELD = typing___cast(AdErrorEnum.AdErrorValue, 8)
        CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET = typing___cast(
            AdErrorEnum.AdErrorValue, 9
        )
        CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING = typing___cast(
            AdErrorEnum.AdErrorValue, 10
        )
        CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE = typing___cast(
            AdErrorEnum.AdErrorValue, 11
        )
        CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING = typing___cast(
            AdErrorEnum.AdErrorValue, 12
        )
        CANNOT_SET_URL = typing___cast(AdErrorEnum.AdErrorValue, 13)
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(AdErrorEnum.AdErrorValue, 14)
        CANNOT_SET_WITH_FINAL_URLS = typing___cast(AdErrorEnum.AdErrorValue, 15)
        CANNOT_SET_WITH_URL_DATA = typing___cast(AdErrorEnum.AdErrorValue, 17)
        CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR = typing___cast(
            AdErrorEnum.AdErrorValue, 18
        )
        CUSTOMER_NOT_APPROVED_MOBILEADS = typing___cast(AdErrorEnum.AdErrorValue, 19)
        CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS = typing___cast(
            AdErrorEnum.AdErrorValue, 20
        )
        CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS = typing___cast(
            AdErrorEnum.AdErrorValue, 21
        )
        CUSTOMER_NOT_ELIGIBLE = typing___cast(AdErrorEnum.AdErrorValue, 22)
        CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL = typing___cast(
            AdErrorEnum.AdErrorValue, 23
        )
        DIMENSION_ALREADY_IN_UNION = typing___cast(AdErrorEnum.AdErrorValue, 24)
        DIMENSION_MUST_BE_SET = typing___cast(AdErrorEnum.AdErrorValue, 25)
        DIMENSION_NOT_IN_UNION = typing___cast(AdErrorEnum.AdErrorValue, 26)
        DISPLAY_URL_CANNOT_BE_SPECIFIED = typing___cast(AdErrorEnum.AdErrorValue, 27)
        DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 28)
        EMERGENCY_PHONE_NUMBER = typing___cast(AdErrorEnum.AdErrorValue, 29)
        EMPTY_FIELD = typing___cast(AdErrorEnum.AdErrorValue, 30)
        FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID = typing___cast(
            AdErrorEnum.AdErrorValue, 31
        )
        FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH = typing___cast(
            AdErrorEnum.AdErrorValue, 32
        )
        ILLEGAL_AD_CUSTOMIZER_TAG_USE = typing___cast(AdErrorEnum.AdErrorValue, 33)
        ILLEGAL_TAG_USE = typing___cast(AdErrorEnum.AdErrorValue, 34)
        INCONSISTENT_DIMENSIONS = typing___cast(AdErrorEnum.AdErrorValue, 35)
        INCONSISTENT_STATUS_IN_TEMPLATE_UNION = typing___cast(
            AdErrorEnum.AdErrorValue, 36
        )
        INCORRECT_LENGTH = typing___cast(AdErrorEnum.AdErrorValue, 37)
        INELIGIBLE_FOR_UPGRADE = typing___cast(AdErrorEnum.AdErrorValue, 38)
        INVALID_AD_ADDRESS_CAMPAIGN_TARGET = typing___cast(AdErrorEnum.AdErrorValue, 39)
        INVALID_AD_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 40)
        INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE = typing___cast(
            AdErrorEnum.AdErrorValue, 41
        )
        INVALID_ATTRIBUTES_FOR_MOBILE_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 42)
        INVALID_CALL_TO_ACTION_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 43)
        INVALID_CHARACTER_FOR_URL = typing___cast(AdErrorEnum.AdErrorValue, 44)
        INVALID_COUNTRY_CODE = typing___cast(AdErrorEnum.AdErrorValue, 45)
        INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG = typing___cast(
            AdErrorEnum.AdErrorValue, 47
        )
        INVALID_INPUT = typing___cast(AdErrorEnum.AdErrorValue, 48)
        INVALID_MARKUP_LANGUAGE = typing___cast(AdErrorEnum.AdErrorValue, 49)
        INVALID_MOBILE_CARRIER = typing___cast(AdErrorEnum.AdErrorValue, 50)
        INVALID_MOBILE_CARRIER_TARGET = typing___cast(AdErrorEnum.AdErrorValue, 51)
        INVALID_NUMBER_OF_ELEMENTS = typing___cast(AdErrorEnum.AdErrorValue, 52)
        INVALID_PHONE_NUMBER_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 53)
        INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID = typing___cast(
            AdErrorEnum.AdErrorValue, 54
        )
        INVALID_TEMPLATE_DATA = typing___cast(AdErrorEnum.AdErrorValue, 55)
        INVALID_TEMPLATE_ELEMENT_FIELD_TYPE = typing___cast(
            AdErrorEnum.AdErrorValue, 56
        )
        INVALID_TEMPLATE_ID = typing___cast(AdErrorEnum.AdErrorValue, 57)
        LINE_TOO_WIDE = typing___cast(AdErrorEnum.AdErrorValue, 58)
        MISSING_AD_CUSTOMIZER_MAPPING = typing___cast(AdErrorEnum.AdErrorValue, 59)
        MISSING_ADDRESS_COMPONENT = typing___cast(AdErrorEnum.AdErrorValue, 60)
        MISSING_ADVERTISEMENT_NAME = typing___cast(AdErrorEnum.AdErrorValue, 61)
        MISSING_BUSINESS_NAME = typing___cast(AdErrorEnum.AdErrorValue, 62)
        MISSING_DESCRIPTION1 = typing___cast(AdErrorEnum.AdErrorValue, 63)
        MISSING_DESCRIPTION2 = typing___cast(AdErrorEnum.AdErrorValue, 64)
        MISSING_DESTINATION_URL_TAG = typing___cast(AdErrorEnum.AdErrorValue, 65)
        MISSING_LANDING_PAGE_URL_TAG = typing___cast(AdErrorEnum.AdErrorValue, 66)
        MISSING_DIMENSION = typing___cast(AdErrorEnum.AdErrorValue, 67)
        MISSING_DISPLAY_URL = typing___cast(AdErrorEnum.AdErrorValue, 68)
        MISSING_HEADLINE = typing___cast(AdErrorEnum.AdErrorValue, 69)
        MISSING_HEIGHT = typing___cast(AdErrorEnum.AdErrorValue, 70)
        MISSING_IMAGE = typing___cast(AdErrorEnum.AdErrorValue, 71)
        MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS = typing___cast(
            AdErrorEnum.AdErrorValue, 72
        )
        MISSING_MARKUP_LANGUAGES = typing___cast(AdErrorEnum.AdErrorValue, 73)
        MISSING_MOBILE_CARRIER = typing___cast(AdErrorEnum.AdErrorValue, 74)
        MISSING_PHONE = typing___cast(AdErrorEnum.AdErrorValue, 75)
        MISSING_REQUIRED_TEMPLATE_FIELDS = typing___cast(AdErrorEnum.AdErrorValue, 76)
        MISSING_TEMPLATE_FIELD_VALUE = typing___cast(AdErrorEnum.AdErrorValue, 77)
        MISSING_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 78)
        MISSING_VISIBLE_URL = typing___cast(AdErrorEnum.AdErrorValue, 79)
        MISSING_WIDTH = typing___cast(AdErrorEnum.AdErrorValue, 80)
        MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED = typing___cast(
            AdErrorEnum.AdErrorValue, 81
        )
        MUST_USE_TEMP_AD_UNION_ID_ON_ADD = typing___cast(AdErrorEnum.AdErrorValue, 82)
        TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 83)
        TOO_SHORT = typing___cast(AdErrorEnum.AdErrorValue, 84)
        UNION_DIMENSIONS_CANNOT_CHANGE = typing___cast(AdErrorEnum.AdErrorValue, 85)
        UNKNOWN_ADDRESS_COMPONENT = typing___cast(AdErrorEnum.AdErrorValue, 86)
        UNKNOWN_FIELD_NAME = typing___cast(AdErrorEnum.AdErrorValue, 87)
        UNKNOWN_UNIQUE_NAME = typing___cast(AdErrorEnum.AdErrorValue, 88)
        UNSUPPORTED_DIMENSIONS = typing___cast(AdErrorEnum.AdErrorValue, 89)
        URL_INVALID_SCHEME = typing___cast(AdErrorEnum.AdErrorValue, 90)
        URL_INVALID_TOP_LEVEL_DOMAIN = typing___cast(AdErrorEnum.AdErrorValue, 91)
        URL_MALFORMED = typing___cast(AdErrorEnum.AdErrorValue, 92)
        URL_NO_HOST = typing___cast(AdErrorEnum.AdErrorValue, 93)
        URL_NOT_EQUIVALENT = typing___cast(AdErrorEnum.AdErrorValue, 94)
        URL_HOST_NAME_TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 95)
        URL_NO_SCHEME = typing___cast(AdErrorEnum.AdErrorValue, 96)
        URL_NO_TOP_LEVEL_DOMAIN = typing___cast(AdErrorEnum.AdErrorValue, 97)
        URL_PATH_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 98)
        URL_PORT_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 99)
        URL_QUERY_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 100)
        URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG = typing___cast(
            AdErrorEnum.AdErrorValue, 102
        )
        USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE = typing___cast(
            AdErrorEnum.AdErrorValue, 103
        )
        INCONSISTENT_EXPANDABLE_SETTINGS = typing___cast(AdErrorEnum.AdErrorValue, 104)
        INVALID_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 105)
        INVALID_FIELD_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 106)
        ELEMENT_NOT_PRESENT = typing___cast(AdErrorEnum.AdErrorValue, 107)
        IMAGE_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 108)
        VALUE_NOT_IN_RANGE = typing___cast(AdErrorEnum.AdErrorValue, 109)
        FIELD_NOT_PRESENT = typing___cast(AdErrorEnum.AdErrorValue, 110)
        ADDRESS_NOT_COMPLETE = typing___cast(AdErrorEnum.AdErrorValue, 111)
        ADDRESS_INVALID = typing___cast(AdErrorEnum.AdErrorValue, 112)
        VIDEO_RETRIEVAL_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 113)
        AUDIO_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 114)
        INVALID_YOUTUBE_DISPLAY_URL = typing___cast(AdErrorEnum.AdErrorValue, 115)
        TOO_MANY_PRODUCT_IMAGES = typing___cast(AdErrorEnum.AdErrorValue, 116)
        TOO_MANY_PRODUCT_VIDEOS = typing___cast(AdErrorEnum.AdErrorValue, 117)
        INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE = typing___cast(
            AdErrorEnum.AdErrorValue, 118
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            AdErrorEnum.AdErrorValue, 119
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
            AdErrorEnum.AdErrorValue, 120
        )
        DISALLOWED_NUMBER_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 121)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            AdErrorEnum.AdErrorValue, 122
        )
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
            AdErrorEnum.AdErrorValue, 123
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 124)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 125)
        INVALID_CALL_CONVERSION_TYPE_ID = typing___cast(AdErrorEnum.AdErrorValue, 126)
        CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID = typing___cast(
            AdErrorEnum.AdErrorValue, 127
        )
        CANNOT_SET_PATH2_WITHOUT_PATH1 = typing___cast(AdErrorEnum.AdErrorValue, 128)
        MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME = typing___cast(
            AdErrorEnum.AdErrorValue, 129
        )
        INCOMPATIBLE_WITH_RESTRICTION_TYPE = typing___cast(
            AdErrorEnum.AdErrorValue, 130
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
            AdErrorEnum.AdErrorValue, 131
        )
        MISSING_IMAGE_OR_MEDIA_BUNDLE = typing___cast(AdErrorEnum.AdErrorValue, 132)
        PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN = typing___cast(
            AdErrorEnum.AdErrorValue, 133
        )
        PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE = typing___cast(
            AdErrorEnum.AdErrorValue, 134
        )
        PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE = typing___cast(
            AdErrorEnum.AdErrorValue, 135
        )
        PLACEHOLDER_DEFAULT_VALUE_MISSING = typing___cast(AdErrorEnum.AdErrorValue, 136)
        UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE = typing___cast(
            AdErrorEnum.AdErrorValue, 137
        )
        AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT = typing___cast(
            AdErrorEnum.AdErrorValue, 138
        )
        UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION = typing___cast(
            AdErrorEnum.AdErrorValue, 139
        )
    UNSPECIFIED = typing___cast(AdErrorEnum.AdErrorValue, 0)
    UNKNOWN = typing___cast(AdErrorEnum.AdErrorValue, 1)
    AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE = typing___cast(
        AdErrorEnum.AdErrorValue, 2
    )
    APPROXIMATELY_TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 3)
    APPROXIMATELY_TOO_SHORT = typing___cast(AdErrorEnum.AdErrorValue, 4)
    BAD_SNIPPET = typing___cast(AdErrorEnum.AdErrorValue, 5)
    CANNOT_MODIFY_AD = typing___cast(AdErrorEnum.AdErrorValue, 6)
    CANNOT_SET_BUSINESS_NAME_IF_URL_SET = typing___cast(AdErrorEnum.AdErrorValue, 7)
    CANNOT_SET_FIELD = typing___cast(AdErrorEnum.AdErrorValue, 8)
    CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET = typing___cast(AdErrorEnum.AdErrorValue, 9)
    CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING = typing___cast(
        AdErrorEnum.AdErrorValue, 10
    )
    CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE = typing___cast(AdErrorEnum.AdErrorValue, 11)
    CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING = typing___cast(
        AdErrorEnum.AdErrorValue, 12
    )
    CANNOT_SET_URL = typing___cast(AdErrorEnum.AdErrorValue, 13)
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(AdErrorEnum.AdErrorValue, 14)
    CANNOT_SET_WITH_FINAL_URLS = typing___cast(AdErrorEnum.AdErrorValue, 15)
    CANNOT_SET_WITH_URL_DATA = typing___cast(AdErrorEnum.AdErrorValue, 17)
    CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR = typing___cast(AdErrorEnum.AdErrorValue, 18)
    CUSTOMER_NOT_APPROVED_MOBILEADS = typing___cast(AdErrorEnum.AdErrorValue, 19)
    CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS = typing___cast(AdErrorEnum.AdErrorValue, 20)
    CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS = typing___cast(
        AdErrorEnum.AdErrorValue, 21
    )
    CUSTOMER_NOT_ELIGIBLE = typing___cast(AdErrorEnum.AdErrorValue, 22)
    CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL = typing___cast(
        AdErrorEnum.AdErrorValue, 23
    )
    DIMENSION_ALREADY_IN_UNION = typing___cast(AdErrorEnum.AdErrorValue, 24)
    DIMENSION_MUST_BE_SET = typing___cast(AdErrorEnum.AdErrorValue, 25)
    DIMENSION_NOT_IN_UNION = typing___cast(AdErrorEnum.AdErrorValue, 26)
    DISPLAY_URL_CANNOT_BE_SPECIFIED = typing___cast(AdErrorEnum.AdErrorValue, 27)
    DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 28)
    EMERGENCY_PHONE_NUMBER = typing___cast(AdErrorEnum.AdErrorValue, 29)
    EMPTY_FIELD = typing___cast(AdErrorEnum.AdErrorValue, 30)
    FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID = typing___cast(
        AdErrorEnum.AdErrorValue, 31
    )
    FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH = typing___cast(AdErrorEnum.AdErrorValue, 32)
    ILLEGAL_AD_CUSTOMIZER_TAG_USE = typing___cast(AdErrorEnum.AdErrorValue, 33)
    ILLEGAL_TAG_USE = typing___cast(AdErrorEnum.AdErrorValue, 34)
    INCONSISTENT_DIMENSIONS = typing___cast(AdErrorEnum.AdErrorValue, 35)
    INCONSISTENT_STATUS_IN_TEMPLATE_UNION = typing___cast(AdErrorEnum.AdErrorValue, 36)
    INCORRECT_LENGTH = typing___cast(AdErrorEnum.AdErrorValue, 37)
    INELIGIBLE_FOR_UPGRADE = typing___cast(AdErrorEnum.AdErrorValue, 38)
    INVALID_AD_ADDRESS_CAMPAIGN_TARGET = typing___cast(AdErrorEnum.AdErrorValue, 39)
    INVALID_AD_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 40)
    INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE = typing___cast(AdErrorEnum.AdErrorValue, 41)
    INVALID_ATTRIBUTES_FOR_MOBILE_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 42)
    INVALID_CALL_TO_ACTION_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 43)
    INVALID_CHARACTER_FOR_URL = typing___cast(AdErrorEnum.AdErrorValue, 44)
    INVALID_COUNTRY_CODE = typing___cast(AdErrorEnum.AdErrorValue, 45)
    INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG = typing___cast(AdErrorEnum.AdErrorValue, 47)
    INVALID_INPUT = typing___cast(AdErrorEnum.AdErrorValue, 48)
    INVALID_MARKUP_LANGUAGE = typing___cast(AdErrorEnum.AdErrorValue, 49)
    INVALID_MOBILE_CARRIER = typing___cast(AdErrorEnum.AdErrorValue, 50)
    INVALID_MOBILE_CARRIER_TARGET = typing___cast(AdErrorEnum.AdErrorValue, 51)
    INVALID_NUMBER_OF_ELEMENTS = typing___cast(AdErrorEnum.AdErrorValue, 52)
    INVALID_PHONE_NUMBER_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 53)
    INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID = typing___cast(
        AdErrorEnum.AdErrorValue, 54
    )
    INVALID_TEMPLATE_DATA = typing___cast(AdErrorEnum.AdErrorValue, 55)
    INVALID_TEMPLATE_ELEMENT_FIELD_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 56)
    INVALID_TEMPLATE_ID = typing___cast(AdErrorEnum.AdErrorValue, 57)
    LINE_TOO_WIDE = typing___cast(AdErrorEnum.AdErrorValue, 58)
    MISSING_AD_CUSTOMIZER_MAPPING = typing___cast(AdErrorEnum.AdErrorValue, 59)
    MISSING_ADDRESS_COMPONENT = typing___cast(AdErrorEnum.AdErrorValue, 60)
    MISSING_ADVERTISEMENT_NAME = typing___cast(AdErrorEnum.AdErrorValue, 61)
    MISSING_BUSINESS_NAME = typing___cast(AdErrorEnum.AdErrorValue, 62)
    MISSING_DESCRIPTION1 = typing___cast(AdErrorEnum.AdErrorValue, 63)
    MISSING_DESCRIPTION2 = typing___cast(AdErrorEnum.AdErrorValue, 64)
    MISSING_DESTINATION_URL_TAG = typing___cast(AdErrorEnum.AdErrorValue, 65)
    MISSING_LANDING_PAGE_URL_TAG = typing___cast(AdErrorEnum.AdErrorValue, 66)
    MISSING_DIMENSION = typing___cast(AdErrorEnum.AdErrorValue, 67)
    MISSING_DISPLAY_URL = typing___cast(AdErrorEnum.AdErrorValue, 68)
    MISSING_HEADLINE = typing___cast(AdErrorEnum.AdErrorValue, 69)
    MISSING_HEIGHT = typing___cast(AdErrorEnum.AdErrorValue, 70)
    MISSING_IMAGE = typing___cast(AdErrorEnum.AdErrorValue, 71)
    MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS = typing___cast(
        AdErrorEnum.AdErrorValue, 72
    )
    MISSING_MARKUP_LANGUAGES = typing___cast(AdErrorEnum.AdErrorValue, 73)
    MISSING_MOBILE_CARRIER = typing___cast(AdErrorEnum.AdErrorValue, 74)
    MISSING_PHONE = typing___cast(AdErrorEnum.AdErrorValue, 75)
    MISSING_REQUIRED_TEMPLATE_FIELDS = typing___cast(AdErrorEnum.AdErrorValue, 76)
    MISSING_TEMPLATE_FIELD_VALUE = typing___cast(AdErrorEnum.AdErrorValue, 77)
    MISSING_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 78)
    MISSING_VISIBLE_URL = typing___cast(AdErrorEnum.AdErrorValue, 79)
    MISSING_WIDTH = typing___cast(AdErrorEnum.AdErrorValue, 80)
    MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED = typing___cast(AdErrorEnum.AdErrorValue, 81)
    MUST_USE_TEMP_AD_UNION_ID_ON_ADD = typing___cast(AdErrorEnum.AdErrorValue, 82)
    TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 83)
    TOO_SHORT = typing___cast(AdErrorEnum.AdErrorValue, 84)
    UNION_DIMENSIONS_CANNOT_CHANGE = typing___cast(AdErrorEnum.AdErrorValue, 85)
    UNKNOWN_ADDRESS_COMPONENT = typing___cast(AdErrorEnum.AdErrorValue, 86)
    UNKNOWN_FIELD_NAME = typing___cast(AdErrorEnum.AdErrorValue, 87)
    UNKNOWN_UNIQUE_NAME = typing___cast(AdErrorEnum.AdErrorValue, 88)
    UNSUPPORTED_DIMENSIONS = typing___cast(AdErrorEnum.AdErrorValue, 89)
    URL_INVALID_SCHEME = typing___cast(AdErrorEnum.AdErrorValue, 90)
    URL_INVALID_TOP_LEVEL_DOMAIN = typing___cast(AdErrorEnum.AdErrorValue, 91)
    URL_MALFORMED = typing___cast(AdErrorEnum.AdErrorValue, 92)
    URL_NO_HOST = typing___cast(AdErrorEnum.AdErrorValue, 93)
    URL_NOT_EQUIVALENT = typing___cast(AdErrorEnum.AdErrorValue, 94)
    URL_HOST_NAME_TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 95)
    URL_NO_SCHEME = typing___cast(AdErrorEnum.AdErrorValue, 96)
    URL_NO_TOP_LEVEL_DOMAIN = typing___cast(AdErrorEnum.AdErrorValue, 97)
    URL_PATH_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 98)
    URL_PORT_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 99)
    URL_QUERY_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 100)
    URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG = typing___cast(
        AdErrorEnum.AdErrorValue, 102
    )
    USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE = typing___cast(AdErrorEnum.AdErrorValue, 103)
    INCONSISTENT_EXPANDABLE_SETTINGS = typing___cast(AdErrorEnum.AdErrorValue, 104)
    INVALID_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 105)
    INVALID_FIELD_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 106)
    ELEMENT_NOT_PRESENT = typing___cast(AdErrorEnum.AdErrorValue, 107)
    IMAGE_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 108)
    VALUE_NOT_IN_RANGE = typing___cast(AdErrorEnum.AdErrorValue, 109)
    FIELD_NOT_PRESENT = typing___cast(AdErrorEnum.AdErrorValue, 110)
    ADDRESS_NOT_COMPLETE = typing___cast(AdErrorEnum.AdErrorValue, 111)
    ADDRESS_INVALID = typing___cast(AdErrorEnum.AdErrorValue, 112)
    VIDEO_RETRIEVAL_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 113)
    AUDIO_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 114)
    INVALID_YOUTUBE_DISPLAY_URL = typing___cast(AdErrorEnum.AdErrorValue, 115)
    TOO_MANY_PRODUCT_IMAGES = typing___cast(AdErrorEnum.AdErrorValue, 116)
    TOO_MANY_PRODUCT_VIDEOS = typing___cast(AdErrorEnum.AdErrorValue, 117)
    INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE = typing___cast(
        AdErrorEnum.AdErrorValue, 118
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        AdErrorEnum.AdErrorValue, 119
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
        AdErrorEnum.AdErrorValue, 120
    )
    DISALLOWED_NUMBER_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 121)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        AdErrorEnum.AdErrorValue, 122
    )
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
        AdErrorEnum.AdErrorValue, 123
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 124)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 125)
    INVALID_CALL_CONVERSION_TYPE_ID = typing___cast(AdErrorEnum.AdErrorValue, 126)
    CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID = typing___cast(
        AdErrorEnum.AdErrorValue, 127
    )
    CANNOT_SET_PATH2_WITHOUT_PATH1 = typing___cast(AdErrorEnum.AdErrorValue, 128)
    MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME = typing___cast(
        AdErrorEnum.AdErrorValue, 129
    )
    INCOMPATIBLE_WITH_RESTRICTION_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 130)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
        AdErrorEnum.AdErrorValue, 131
    )
    MISSING_IMAGE_OR_MEDIA_BUNDLE = typing___cast(AdErrorEnum.AdErrorValue, 132)
    PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN = typing___cast(
        AdErrorEnum.AdErrorValue, 133
    )
    PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE = typing___cast(
        AdErrorEnum.AdErrorValue, 134
    )
    PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE = typing___cast(
        AdErrorEnum.AdErrorValue, 135
    )
    PLACEHOLDER_DEFAULT_VALUE_MISSING = typing___cast(AdErrorEnum.AdErrorValue, 136)
    UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE = typing___cast(AdErrorEnum.AdErrorValue, 137)
    AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT = typing___cast(AdErrorEnum.AdErrorValue, 138)
    UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION = typing___cast(
        AdErrorEnum.AdErrorValue, 139
    )
    type___AdError = AdError
    def __init__(self,) -> None: ...

type___AdErrorEnum = AdErrorEnum



from typing import Any

class VideoServiceStub:
    GetVideo: Any = ...
    def __init__(self, channel: Any) -> None: ...

class VideoServiceServicer:
    def GetVideo(self, request: Any, context: Any) -> None: ...

def add_VideoServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.criteria_pb2 import (
    InteractionTypeInfo as google___ads___googleads___v3___common___criteria_pb2___InteractionTypeInfo,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignBidModifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def interaction_type(
        self,
    ) -> google___ads___googleads___v3___common___criteria_pb2___InteractionTypeInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        criterion_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        bid_modifier: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        interaction_type: typing___Optional[
            google___ads___googleads___v3___common___criteria_pb2___InteractionTypeInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "bid_modifier",
            b"bid_modifier",
            "campaign",
            b"campaign",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "interaction_type",
            b"interaction_type",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "bid_modifier",
            b"bid_modifier",
            "campaign",
            b"campaign",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "interaction_type",
            b"interaction_type",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["criterion", b"criterion"]
    ) -> typing_extensions___Literal["interaction_type"]: ...

type___CampaignBidModifier = CampaignBidModifier



from typing import Any

class ManagedPlacementViewServiceStub:
    GetManagedPlacementView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ManagedPlacementViewServiceServicer:
    def GetManagedPlacementView(self, request: Any, context: Any) -> None: ...

def add_ManagedPlacementViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DatabaseErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DatabaseErrorValue = typing___NewType("DatabaseErrorValue", builtin___int)
    type___DatabaseErrorValue = DatabaseErrorValue
    DatabaseError: _DatabaseError
    class _DatabaseError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DatabaseErrorEnum.DatabaseErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 0)
        UNKNOWN = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 1)
        CONCURRENT_MODIFICATION = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 2)
        DATA_CONSTRAINT_VIOLATION = typing___cast(
            DatabaseErrorEnum.DatabaseErrorValue, 3
        )
        REQUEST_TOO_LARGE = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 4)
    UNSPECIFIED = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 0)
    UNKNOWN = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 1)
    CONCURRENT_MODIFICATION = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 2)
    DATA_CONSTRAINT_VIOLATION = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 3)
    REQUEST_TOO_LARGE = typing___cast(DatabaseErrorEnum.DatabaseErrorValue, 4)
    type___DatabaseError = DatabaseError
    def __init__(self,) -> None: ...

type___DatabaseErrorEnum = DatabaseErrorEnum



from typing import Any

class GeoTargetConstantServiceStub:
    GetGeoTargetConstant: Any = ...
    SuggestGeoTargetConstants: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GeoTargetConstantServiceServicer:
    def GetGeoTargetConstant(self, request: Any, context: Any) -> None: ...
    def SuggestGeoTargetConstants(self, request: Any, context: Any) -> None: ...

def add_GeoTargetConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class UserLocationViewServiceStub:
    GetUserLocationView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class UserLocationViewServiceServicer:
    def GetUserLocationView(self, request: Any, context: Any) -> None: ...

def add_UserLocationViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class LandingPageViewServiceStub:
    GetLandingPageView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class LandingPageViewServiceServicer:
    def GetLandingPageView(self, request: Any, context: Any) -> None: ...

def add_LandingPageViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class CustomerClientLinkServiceStub:
    GetCustomerClientLink: Any = ...
    MutateCustomerClientLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerClientLinkServiceServicer:
    def GetCustomerClientLink(self, request: Any, context: Any) -> None: ...
    def MutateCustomerClientLink(self, request: Any, context: Any) -> None: ...

def add_CustomerClientLinkServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExtensionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ExtensionTypeValue = typing___NewType("ExtensionTypeValue", builtin___int)
    type___ExtensionTypeValue = ExtensionTypeValue
    ExtensionType: _ExtensionType
    class _ExtensionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ExtensionTypeEnum.ExtensionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 0)
        UNKNOWN = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 1)
        NONE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 2)
        APP = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 3)
        CALL = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 4)
        CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 5)
        MESSAGE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 6)
        PRICE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 7)
        PROMOTION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 8)
        SITELINK = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 10)
        STRUCTURED_SNIPPET = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 11)
        LOCATION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 12)
        AFFILIATE_LOCATION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 13)
        HOTEL_CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 15)
        IMAGE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 16)
    UNSPECIFIED = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 0)
    UNKNOWN = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 1)
    NONE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 2)
    APP = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 3)
    CALL = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 4)
    CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 5)
    MESSAGE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 6)
    PRICE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 7)
    PROMOTION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 8)
    SITELINK = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 10)
    STRUCTURED_SNIPPET = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 11)
    LOCATION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 12)
    AFFILIATE_LOCATION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 13)
    HOTEL_CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 15)
    IMAGE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 16)
    type___ExtensionType = ExtensionType
    def __init__(self,) -> None: ...

type___ExtensionTypeEnum = ExtensionTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.tag_snippet_pb2 import (
    TagSnippet as google___ads___googleads___v5___common___tag_snippet_pb2___TagSnippet,
)
from google.ads.google_ads.v5.proto.enums.attribution_model_pb2 import (
    AttributionModelEnum as google___ads___googleads___v5___enums___attribution_model_pb2___AttributionModelEnum,
)
from google.ads.google_ads.v5.proto.enums.conversion_action_category_pb2 import (
    ConversionActionCategoryEnum as google___ads___googleads___v5___enums___conversion_action_category_pb2___ConversionActionCategoryEnum,
)
from google.ads.google_ads.v5.proto.enums.conversion_action_counting_type_pb2 import (
    ConversionActionCountingTypeEnum as google___ads___googleads___v5___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.conversion_action_status_pb2 import (
    ConversionActionStatusEnum as google___ads___googleads___v5___enums___conversion_action_status_pb2___ConversionActionStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.conversion_action_type_pb2 import (
    ConversionActionTypeEnum as google___ads___googleads___v5___enums___conversion_action_type_pb2___ConversionActionTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.data_driven_model_status_pb2 import (
    DataDrivenModelStatusEnum as google___ads___googleads___v5___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.mobile_app_vendor_pb2 import (
    MobileAppVendorEnum as google___ads___googleads___v5___enums___mobile_app_vendor_pb2___MobileAppVendorEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionAction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AttributionModelSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        attribution_model: google___ads___googleads___v5___enums___attribution_model_pb2___AttributionModelEnum.AttributionModelValue = ...
        data_driven_model_status: google___ads___googleads___v5___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum.DataDrivenModelStatusValue = ...
        def __init__(
            self,
            *,
            attribution_model: typing___Optional[
                google___ads___googleads___v5___enums___attribution_model_pb2___AttributionModelEnum.AttributionModelValue
            ] = None,
            data_driven_model_status: typing___Optional[
                google___ads___googleads___v5___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum.DataDrivenModelStatusValue
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "attribution_model",
                b"attribution_model",
                "data_driven_model_status",
                b"data_driven_model_status",
            ],
        ) -> None: ...
    type___AttributionModelSettings = AttributionModelSettings
    class ValueSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        default_value: builtin___float = ...
        default_currency_code: typing___Text = ...
        always_use_default_value: builtin___bool = ...
        def __init__(
            self,
            *,
            default_value: typing___Optional[builtin___float] = None,
            default_currency_code: typing___Optional[typing___Text] = None,
            always_use_default_value: typing___Optional[builtin___bool] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_always_use_default_value",
                b"_always_use_default_value",
                "_default_currency_code",
                b"_default_currency_code",
                "_default_value",
                b"_default_value",
                "always_use_default_value",
                b"always_use_default_value",
                "default_currency_code",
                b"default_currency_code",
                "default_value",
                b"default_value",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_always_use_default_value",
                b"_always_use_default_value",
                "_default_currency_code",
                b"_default_currency_code",
                "_default_value",
                b"_default_value",
                "always_use_default_value",
                b"always_use_default_value",
                "default_currency_code",
                b"default_currency_code",
                "default_value",
                b"default_value",
            ],
        ) -> None: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_always_use_default_value", b"_always_use_default_value"
            ],
        ) -> typing_extensions___Literal["always_use_default_value"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_default_currency_code", b"_default_currency_code"
            ],
        ) -> typing_extensions___Literal["default_currency_code"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_default_value", b"_default_value"
            ],
        ) -> typing_extensions___Literal["default_value"]: ...
    type___ValueSettings = ValueSettings
    class ThirdPartyAppAnalyticsSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        event_name: typing___Text = ...
        def __init__(
            self, *, event_name: typing___Optional[typing___Text] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_event_name", b"_event_name", "event_name", b"event_name"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_event_name", b"_event_name", "event_name", b"event_name"
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal["_event_name", b"_event_name"],
        ) -> typing_extensions___Literal["event_name"]: ...
    type___ThirdPartyAppAnalyticsSettings = ThirdPartyAppAnalyticsSettings
    class FirebaseSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        event_name: typing___Text = ...
        project_id: typing___Text = ...
        def __init__(
            self,
            *,
            event_name: typing___Optional[typing___Text] = None,
            project_id: typing___Optional[typing___Text] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_event_name",
                b"_event_name",
                "_project_id",
                b"_project_id",
                "event_name",
                b"event_name",
                "project_id",
                b"project_id",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_event_name",
                b"_event_name",
                "_project_id",
                b"_project_id",
                "event_name",
                b"event_name",
                "project_id",
                b"project_id",
            ],
        ) -> None: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal["_event_name", b"_event_name"],
        ) -> typing_extensions___Literal["event_name"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal["_project_id", b"_project_id"],
        ) -> typing_extensions___Literal["project_id"]: ...
    type___FirebaseSettings = FirebaseSettings

    resource_name: typing___Text = ...
    id: builtin___int = ...
    name: typing___Text = ...
    status: google___ads___googleads___v5___enums___conversion_action_status_pb2___ConversionActionStatusEnum.ConversionActionStatusValue = ...
    type: google___ads___googleads___v5___enums___conversion_action_type_pb2___ConversionActionTypeEnum.ConversionActionTypeValue = ...
    category: google___ads___googleads___v5___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategoryValue = ...
    owner_customer: typing___Text = ...
    include_in_conversions_metric: builtin___bool = ...
    click_through_lookback_window_days: builtin___int = ...
    view_through_lookback_window_days: builtin___int = ...
    counting_type: google___ads___googleads___v5___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum.ConversionActionCountingTypeValue = ...
    phone_call_duration_seconds: builtin___int = ...
    app_id: typing___Text = ...
    mobile_app_vendor: google___ads___googleads___v5___enums___mobile_app_vendor_pb2___MobileAppVendorEnum.MobileAppVendorValue = ...
    @property
    def value_settings(self) -> type___ConversionAction.ValueSettings: ...
    @property
    def attribution_model_settings(
        self,
    ) -> type___ConversionAction.AttributionModelSettings: ...
    @property
    def tag_snippets(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v5___common___tag_snippet_pb2___TagSnippet
    ]: ...
    @property
    def firebase_settings(self) -> type___ConversionAction.FirebaseSettings: ...
    @property
    def third_party_app_analytics_settings(
        self,
    ) -> type___ConversionAction.ThirdPartyAppAnalyticsSettings: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        name: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___conversion_action_status_pb2___ConversionActionStatusEnum.ConversionActionStatusValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v5___enums___conversion_action_type_pb2___ConversionActionTypeEnum.ConversionActionTypeValue
        ] = None,
        category: typing___Optional[
            google___ads___googleads___v5___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategoryValue
        ] = None,
        owner_customer: typing___Optional[typing___Text] = None,
        include_in_conversions_metric: typing___Optional[builtin___bool] = None,
        click_through_lookback_window_days: typing___Optional[builtin___int] = None,
        view_through_lookback_window_days: typing___Optional[builtin___int] = None,
        value_settings: typing___Optional[type___ConversionAction.ValueSettings] = None,
        counting_type: typing___Optional[
            google___ads___googleads___v5___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum.ConversionActionCountingTypeValue
        ] = None,
        attribution_model_settings: typing___Optional[
            type___ConversionAction.AttributionModelSettings
        ] = None,
        tag_snippets: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___common___tag_snippet_pb2___TagSnippet
            ]
        ] = None,
        phone_call_duration_seconds: typing___Optional[builtin___int] = None,
        app_id: typing___Optional[typing___Text] = None,
        mobile_app_vendor: typing___Optional[
            google___ads___googleads___v5___enums___mobile_app_vendor_pb2___MobileAppVendorEnum.MobileAppVendorValue
        ] = None,
        firebase_settings: typing___Optional[
            type___ConversionAction.FirebaseSettings
        ] = None,
        third_party_app_analytics_settings: typing___Optional[
            type___ConversionAction.ThirdPartyAppAnalyticsSettings
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_app_id",
            b"_app_id",
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
            "_id",
            b"_id",
            "_include_in_conversions_metric",
            b"_include_in_conversions_metric",
            "_name",
            b"_name",
            "_owner_customer",
            b"_owner_customer",
            "_phone_call_duration_seconds",
            b"_phone_call_duration_seconds",
            "_view_through_lookback_window_days",
            b"_view_through_lookback_window_days",
            "app_id",
            b"app_id",
            "attribution_model_settings",
            b"attribution_model_settings",
            "click_through_lookback_window_days",
            b"click_through_lookback_window_days",
            "firebase_settings",
            b"firebase_settings",
            "id",
            b"id",
            "include_in_conversions_metric",
            b"include_in_conversions_metric",
            "name",
            b"name",
            "owner_customer",
            b"owner_customer",
            "phone_call_duration_seconds",
            b"phone_call_duration_seconds",
            "third_party_app_analytics_settings",
            b"third_party_app_analytics_settings",
            "value_settings",
            b"value_settings",
            "view_through_lookback_window_days",
            b"view_through_lookback_window_days",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_app_id",
            b"_app_id",
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
            "_id",
            b"_id",
            "_include_in_conversions_metric",
            b"_include_in_conversions_metric",
            "_name",
            b"_name",
            "_owner_customer",
            b"_owner_customer",
            "_phone_call_duration_seconds",
            b"_phone_call_duration_seconds",
            "_view_through_lookback_window_days",
            b"_view_through_lookback_window_days",
            "app_id",
            b"app_id",
            "attribution_model_settings",
            b"attribution_model_settings",
            "category",
            b"category",
            "click_through_lookback_window_days",
            b"click_through_lookback_window_days",
            "counting_type",
            b"counting_type",
            "firebase_settings",
            b"firebase_settings",
            "id",
            b"id",
            "include_in_conversions_metric",
            b"include_in_conversions_metric",
            "mobile_app_vendor",
            b"mobile_app_vendor",
            "name",
            b"name",
            "owner_customer",
            b"owner_customer",
            "phone_call_duration_seconds",
            b"phone_call_duration_seconds",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "tag_snippets",
            b"tag_snippets",
            "third_party_app_analytics_settings",
            b"third_party_app_analytics_settings",
            "type",
            b"type",
            "value_settings",
            b"value_settings",
            "view_through_lookback_window_days",
            b"view_through_lookback_window_days",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_app_id", b"_app_id"]
    ) -> typing_extensions___Literal["app_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
        ],
    ) -> typing_extensions___Literal["click_through_lookback_window_days"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_include_in_conversions_metric", b"_include_in_conversions_metric"
        ],
    ) -> typing_extensions___Literal["include_in_conversions_metric"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_owner_customer", b"_owner_customer"],
    ) -> typing_extensions___Literal["owner_customer"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_phone_call_duration_seconds", b"_phone_call_duration_seconds"
        ],
    ) -> typing_extensions___Literal["phone_call_duration_seconds"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_view_through_lookback_window_days", b"_view_through_lookback_window_days"
        ],
    ) -> typing_extensions___Literal["view_through_lookback_window_days"]: ...

type___ConversionAction = ConversionAction



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MediaBundleErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MediaBundleErrorValue = typing___NewType("MediaBundleErrorValue", builtin___int)
    type___MediaBundleErrorValue = MediaBundleErrorValue
    MediaBundleError: _MediaBundleError
    class _MediaBundleError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MediaBundleErrorEnum.MediaBundleErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 0)
        UNKNOWN = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 1)
        BAD_REQUEST = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 3)
        DOUBLECLICK_BUNDLE_NOT_ALLOWED = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 4
        )
        EXTERNAL_URL_NOT_ALLOWED = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 5
        )
        FILE_TOO_LARGE = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 6)
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 7
        )
        INVALID_INPUT = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 8)
        INVALID_MEDIA_BUNDLE = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 9
        )
        INVALID_MEDIA_BUNDLE_ENTRY = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 10
        )
        INVALID_MIME_TYPE = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 11
        )
        INVALID_PATH = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 12)
        INVALID_URL_REFERENCE = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 13
        )
        MEDIA_DATA_TOO_LARGE = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 14
        )
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 15
        )
        SERVER_ERROR = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 16)
        STORAGE_ERROR = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 17)
        SWIFFY_BUNDLE_NOT_ALLOWED = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 18
        )
        TOO_MANY_FILES = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 19)
        UNEXPECTED_SIZE = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 20)
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 21
        )
        UNSUPPORTED_HTML5_FEATURE = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 22
        )
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 23
        )
        CUSTOM_EXIT_NOT_ALLOWED = typing___cast(
            MediaBundleErrorEnum.MediaBundleErrorValue, 24
        )
    UNSPECIFIED = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 0)
    UNKNOWN = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 1)
    BAD_REQUEST = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 3)
    DOUBLECLICK_BUNDLE_NOT_ALLOWED = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 4
    )
    EXTERNAL_URL_NOT_ALLOWED = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 5
    )
    FILE_TOO_LARGE = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 6)
    GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 7
    )
    INVALID_INPUT = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 8)
    INVALID_MEDIA_BUNDLE = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 9)
    INVALID_MEDIA_BUNDLE_ENTRY = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 10
    )
    INVALID_MIME_TYPE = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 11)
    INVALID_PATH = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 12)
    INVALID_URL_REFERENCE = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 13
    )
    MEDIA_DATA_TOO_LARGE = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 14)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 15
    )
    SERVER_ERROR = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 16)
    STORAGE_ERROR = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 17)
    SWIFFY_BUNDLE_NOT_ALLOWED = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 18
    )
    TOO_MANY_FILES = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 19)
    UNEXPECTED_SIZE = typing___cast(MediaBundleErrorEnum.MediaBundleErrorValue, 20)
    UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 21
    )
    UNSUPPORTED_HTML5_FEATURE = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 22
    )
    URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 23
    )
    CUSTOM_EXIT_NOT_ALLOWED = typing___cast(
        MediaBundleErrorEnum.MediaBundleErrorValue, 24
    )
    type___MediaBundleError = MediaBundleError
    def __init__(self,) -> None: ...

type___MediaBundleErrorEnum = MediaBundleErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdDestinationTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdDestinationTypeValue = typing___NewType("AdDestinationTypeValue", builtin___int)
    type___AdDestinationTypeValue = AdDestinationTypeValue
    AdDestinationType: _AdDestinationType
    class _AdDestinationType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdDestinationTypeEnum.AdDestinationTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 0)
        UNKNOWN = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 1)
        NOT_APPLICABLE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 2)
        WEBSITE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 3)
        APP_DEEP_LINK = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 4)
        APP_STORE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 5)
        PHONE_CALL = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 6)
        MAP_DIRECTIONS = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 7)
        LOCATION_LISTING = typing___cast(
            AdDestinationTypeEnum.AdDestinationTypeValue, 8
        )
        MESSAGE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 9)
        LEAD_FORM = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 10)
        YOUTUBE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 11)
        UNMODELED_FOR_CONVERSIONS = typing___cast(
            AdDestinationTypeEnum.AdDestinationTypeValue, 12
        )
    UNSPECIFIED = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 0)
    UNKNOWN = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 1)
    NOT_APPLICABLE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 2)
    WEBSITE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 3)
    APP_DEEP_LINK = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 4)
    APP_STORE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 5)
    PHONE_CALL = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 6)
    MAP_DIRECTIONS = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 7)
    LOCATION_LISTING = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 8)
    MESSAGE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 9)
    LEAD_FORM = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 10)
    YOUTUBE = typing___cast(AdDestinationTypeEnum.AdDestinationTypeValue, 11)
    UNMODELED_FOR_CONVERSIONS = typing___cast(
        AdDestinationTypeEnum.AdDestinationTypeValue, 12
    )
    type___AdDestinationType = AdDestinationType
    def __init__(self,) -> None: ...

type___AdDestinationTypeEnum = AdDestinationTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MonthOfYearEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MonthOfYearValue = typing___NewType("MonthOfYearValue", builtin___int)
    type___MonthOfYearValue = MonthOfYearValue
    MonthOfYear: _MonthOfYear
    class _MonthOfYear(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MonthOfYearEnum.MonthOfYearValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MonthOfYearEnum.MonthOfYearValue, 0)
        UNKNOWN = typing___cast(MonthOfYearEnum.MonthOfYearValue, 1)
        JANUARY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 2)
        FEBRUARY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 3)
        MARCH = typing___cast(MonthOfYearEnum.MonthOfYearValue, 4)
        APRIL = typing___cast(MonthOfYearEnum.MonthOfYearValue, 5)
        MAY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 6)
        JUNE = typing___cast(MonthOfYearEnum.MonthOfYearValue, 7)
        JULY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 8)
        AUGUST = typing___cast(MonthOfYearEnum.MonthOfYearValue, 9)
        SEPTEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 10)
        OCTOBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 11)
        NOVEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 12)
        DECEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 13)
    UNSPECIFIED = typing___cast(MonthOfYearEnum.MonthOfYearValue, 0)
    UNKNOWN = typing___cast(MonthOfYearEnum.MonthOfYearValue, 1)
    JANUARY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 2)
    FEBRUARY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 3)
    MARCH = typing___cast(MonthOfYearEnum.MonthOfYearValue, 4)
    APRIL = typing___cast(MonthOfYearEnum.MonthOfYearValue, 5)
    MAY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 6)
    JUNE = typing___cast(MonthOfYearEnum.MonthOfYearValue, 7)
    JULY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 8)
    AUGUST = typing___cast(MonthOfYearEnum.MonthOfYearValue, 9)
    SEPTEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 10)
    OCTOBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 11)
    NOVEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 12)
    DECEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 13)
    type___MonthOfYear = MonthOfYear
    def __init__(self,) -> None: ...

type___MonthOfYearEnum = MonthOfYearEnum



from typing import Any

class AdGroupCriterionServiceStub:
    GetAdGroupCriterion: Any = ...
    MutateAdGroupCriteria: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupCriterionServiceServicer:
    def GetAdGroupCriterion(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupCriteria(self, request: Any, context: Any) -> None: ...

def add_AdGroupCriterionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.product_bidding_category_level_pb2 import (
    ProductBiddingCategoryLevelEnum as google___ads___googleads___v6___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum,
)
from google.ads.google_ads.v6.proto.enums.product_bidding_category_status_pb2 import (
    ProductBiddingCategoryStatusEnum as google___ads___googleads___v6___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ProductBiddingCategoryConstant(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    country_code: typing___Text = ...
    product_bidding_category_constant_parent: typing___Text = ...
    level: google___ads___googleads___v6___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue = ...
    status: google___ads___googleads___v6___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatusValue = ...
    language_code: typing___Text = ...
    localized_name: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        country_code: typing___Optional[typing___Text] = None,
        product_bidding_category_constant_parent: typing___Optional[
            typing___Text
        ] = None,
        level: typing___Optional[
            google___ads___googleads___v6___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatusValue
        ] = None,
        language_code: typing___Optional[typing___Text] = None,
        localized_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_language_code",
            b"_language_code",
            "_localized_name",
            b"_localized_name",
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "language_code",
            b"language_code",
            "localized_name",
            b"localized_name",
            "product_bidding_category_constant_parent",
            b"product_bidding_category_constant_parent",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_language_code",
            b"_language_code",
            "_localized_name",
            b"_localized_name",
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "language_code",
            b"language_code",
            "level",
            b"level",
            "localized_name",
            b"localized_name",
            "product_bidding_category_constant_parent",
            b"product_bidding_category_constant_parent",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_country_code", b"_country_code"],
    ) -> typing_extensions___Literal["country_code"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_language_code", b"_language_code"],
    ) -> typing_extensions___Literal["language_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_localized_name", b"_localized_name"],
    ) -> typing_extensions___Literal["localized_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
        ],
    ) -> typing_extensions___Literal["product_bidding_category_constant_parent"]: ...

type___ProductBiddingCategoryConstant = ProductBiddingCategoryConstant



from typing import Any

class UserInterestServiceStub:
    GetUserInterest: Any = ...
    def __init__(self, channel: Any) -> None: ...

class UserInterestServiceServicer:
    def GetUserInterest(self, request: Any, context: Any) -> None: ...

def add_UserInterestServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import Any

class AdGroupFeedServiceStub:
    GetAdGroupFeed: Any = ...
    MutateAdGroupFeeds: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupFeedServiceServicer:
    def GetAdGroupFeed(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupFeeds(self, request: Any, context: Any) -> None: ...

def add_AdGroupFeedServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionLagBucketEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionLagBucketValue = typing___NewType(
        "ConversionLagBucketValue", builtin___int
    )
    type___ConversionLagBucketValue = ConversionLagBucketValue
    ConversionLagBucket: _ConversionLagBucket
    class _ConversionLagBucket(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionLagBucketEnum.ConversionLagBucketValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ConversionLagBucketEnum.ConversionLagBucketValue, 0)
        UNKNOWN = typing___cast(ConversionLagBucketEnum.ConversionLagBucketValue, 1)
        LESS_THAN_ONE_DAY = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 2
        )
        ONE_TO_TWO_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 3
        )
        TWO_TO_THREE_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 4
        )
        THREE_TO_FOUR_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 5
        )
        FOUR_TO_FIVE_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 6
        )
        FIVE_TO_SIX_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 7
        )
        SIX_TO_SEVEN_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 8
        )
        SEVEN_TO_EIGHT_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 9
        )
        EIGHT_TO_NINE_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 10
        )
        NINE_TO_TEN_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 11
        )
        TEN_TO_ELEVEN_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 12
        )
        ELEVEN_TO_TWELVE_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 13
        )
        TWELVE_TO_THIRTEEN_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 14
        )
        THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 15
        )
        FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 16
        )
        TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 17
        )
        THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 18
        )
        FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 19
        )
        SIXTY_TO_NINETY_DAYS = typing___cast(
            ConversionLagBucketEnum.ConversionLagBucketValue, 20
        )
    UNSPECIFIED = typing___cast(ConversionLagBucketEnum.ConversionLagBucketValue, 0)
    UNKNOWN = typing___cast(ConversionLagBucketEnum.ConversionLagBucketValue, 1)
    LESS_THAN_ONE_DAY = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 2
    )
    ONE_TO_TWO_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucketValue, 3)
    TWO_TO_THREE_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 4
    )
    THREE_TO_FOUR_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 5
    )
    FOUR_TO_FIVE_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 6
    )
    FIVE_TO_SIX_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 7
    )
    SIX_TO_SEVEN_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 8
    )
    SEVEN_TO_EIGHT_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 9
    )
    EIGHT_TO_NINE_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 10
    )
    NINE_TO_TEN_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 11
    )
    TEN_TO_ELEVEN_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 12
    )
    ELEVEN_TO_TWELVE_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 13
    )
    TWELVE_TO_THIRTEEN_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 14
    )
    THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 15
    )
    FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 16
    )
    TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 17
    )
    THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 18
    )
    FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 19
    )
    SIXTY_TO_NINETY_DAYS = typing___cast(
        ConversionLagBucketEnum.ConversionLagBucketValue, 20
    )
    type___ConversionLagBucket = ConversionLagBucket
    def __init__(self,) -> None: ...

type___ConversionLagBucketEnum = ConversionLagBucketEnum



from typing import Any

class TopicViewServiceStub:
    GetTopicView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class TopicViewServiceServicer:
    def GetTopicView(self, request: Any, context: Any) -> None: ...

def add_TopicViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Iterable as typing___Iterable, Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.matching_function_context_type_pb2 import (
    MatchingFunctionContextTypeEnum as google___ads___googleads___v5___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.matching_function_operator_pb2 import (
    MatchingFunctionOperatorEnum as google___ads___googleads___v5___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MatchingFunction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operator: google___ads___googleads___v5___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue = ...
    @property
    def function_string(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def left_operands(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___Operand
    ]: ...
    @property
    def right_operands(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___Operand
    ]: ...
    def __init__(
        self,
        *,
        function_string: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        operator: typing___Optional[
            google___ads___googleads___v5___enums___matching_function_operator_pb2___MatchingFunctionOperatorEnum.MatchingFunctionOperatorValue
        ] = None,
        left_operands: typing___Optional[typing___Iterable[type___Operand]] = None,
        right_operands: typing___Optional[typing___Iterable[type___Operand]] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["function_string", b"function_string"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "function_string",
            b"function_string",
            "left_operands",
            b"left_operands",
            "operator",
            b"operator",
            "right_operands",
            b"right_operands",
        ],
    ) -> None: ...

type___MatchingFunction = MatchingFunction

class Operand(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ConstantOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def string_value(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def long_value(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def boolean_value(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def double_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
        def __init__(
            self,
            *,
            string_value: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            long_value: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            boolean_value: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            double_value: typing___Optional[
                google___protobuf___wrappers_pb2___DoubleValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "boolean_value",
                b"boolean_value",
                "constant_operand_value",
                b"constant_operand_value",
                "double_value",
                b"double_value",
                "long_value",
                b"long_value",
                "string_value",
                b"string_value",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "boolean_value",
                b"boolean_value",
                "constant_operand_value",
                b"constant_operand_value",
                "double_value",
                b"double_value",
                "long_value",
                b"long_value",
                "string_value",
                b"string_value",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "constant_operand_value", b"constant_operand_value"
            ],
        ) -> typing_extensions___Literal[
            "string_value", "long_value", "boolean_value", "double_value"
        ]: ...
    type___ConstantOperand = ConstantOperand
    class FeedAttributeOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def feed_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def feed_attribute_id(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            feed_id: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            feed_attribute_id: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "feed_attribute_id", b"feed_attribute_id", "feed_id", b"feed_id"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "feed_attribute_id", b"feed_attribute_id", "feed_id", b"feed_id"
            ],
        ) -> None: ...
    type___FeedAttributeOperand = FeedAttributeOperand
    class FunctionOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def matching_function(self) -> type___MatchingFunction: ...
        def __init__(
            self,
            *,
            matching_function: typing___Optional[type___MatchingFunction] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "matching_function", b"matching_function"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "matching_function", b"matching_function"
            ],
        ) -> None: ...
    type___FunctionOperand = FunctionOperand
    class RequestContextOperand(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        context_type: google___ads___googleads___v5___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum.MatchingFunctionContextTypeValue = ...
        def __init__(
            self,
            *,
            context_type: typing___Optional[
                google___ads___googleads___v5___enums___matching_function_context_type_pb2___MatchingFunctionContextTypeEnum.MatchingFunctionContextTypeValue
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal["context_type", b"context_type"],
        ) -> None: ...
    type___RequestContextOperand = RequestContextOperand
    @property
    def constant_operand(self) -> type___Operand.ConstantOperand: ...
    @property
    def feed_attribute_operand(self) -> type___Operand.FeedAttributeOperand: ...
    @property
    def function_operand(self) -> type___Operand.FunctionOperand: ...
    @property
    def request_context_operand(self) -> type___Operand.RequestContextOperand: ...
    def __init__(
        self,
        *,
        constant_operand: typing___Optional[type___Operand.ConstantOperand] = None,
        feed_attribute_operand: typing___Optional[
            type___Operand.FeedAttributeOperand
        ] = None,
        function_operand: typing___Optional[type___Operand.FunctionOperand] = None,
        request_context_operand: typing___Optional[
            type___Operand.RequestContextOperand
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "constant_operand",
            b"constant_operand",
            "feed_attribute_operand",
            b"feed_attribute_operand",
            "function_argument_operand",
            b"function_argument_operand",
            "function_operand",
            b"function_operand",
            "request_context_operand",
            b"request_context_operand",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "constant_operand",
            b"constant_operand",
            "feed_attribute_operand",
            b"feed_attribute_operand",
            "function_argument_operand",
            b"function_argument_operand",
            "function_operand",
            b"function_operand",
            "request_context_operand",
            b"request_context_operand",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "function_argument_operand", b"function_argument_operand"
        ],
    ) -> typing_extensions___Literal[
        "constant_operand",
        "feed_attribute_operand",
        "function_operand",
        "request_context_operand",
    ]: ...

type___Operand = Operand



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class RecommendationTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    RecommendationTypeValue = typing___NewType("RecommendationTypeValue", builtin___int)
    type___RecommendationTypeValue = RecommendationTypeValue
    RecommendationType: _RecommendationType
    class _RecommendationType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            RecommendationTypeEnum.RecommendationTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 0)
        UNKNOWN = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 1)
        CAMPAIGN_BUDGET = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 2
        )
        KEYWORD = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 3)
        TEXT_AD = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 4)
        TARGET_CPA_OPT_IN = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 5
        )
        MAXIMIZE_CONVERSIONS_OPT_IN = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 6
        )
        ENHANCED_CPC_OPT_IN = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 7
        )
        SEARCH_PARTNERS_OPT_IN = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 8
        )
        MAXIMIZE_CLICKS_OPT_IN = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 9
        )
        OPTIMIZE_AD_ROTATION = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 10
        )
        CALLOUT_EXTENSION = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 11
        )
        SITELINK_EXTENSION = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 12
        )
        CALL_EXTENSION = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 13
        )
        KEYWORD_MATCH_TYPE = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 14
        )
        MOVE_UNUSED_BUDGET = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 15
        )
        TARGET_ROAS_OPT_IN = typing___cast(
            RecommendationTypeEnum.RecommendationTypeValue, 17
        )
    UNSPECIFIED = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 0)
    UNKNOWN = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 1)
    CAMPAIGN_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 2)
    KEYWORD = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 3)
    TEXT_AD = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 4)
    TARGET_CPA_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 5)
    MAXIMIZE_CONVERSIONS_OPT_IN = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 6
    )
    ENHANCED_CPC_OPT_IN = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 7
    )
    SEARCH_PARTNERS_OPT_IN = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 8
    )
    MAXIMIZE_CLICKS_OPT_IN = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 9
    )
    OPTIMIZE_AD_ROTATION = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 10
    )
    CALLOUT_EXTENSION = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 11
    )
    SITELINK_EXTENSION = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 12
    )
    CALL_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationTypeValue, 13)
    KEYWORD_MATCH_TYPE = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 14
    )
    MOVE_UNUSED_BUDGET = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 15
    )
    TARGET_ROAS_OPT_IN = typing___cast(
        RecommendationTypeEnum.RecommendationTypeValue, 17
    )
    type___RecommendationType = RecommendationType
    def __init__(self,) -> None: ...

type___RecommendationTypeEnum = RecommendationTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TargetingDimensionEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TargetingDimensionValue = typing___NewType("TargetingDimensionValue", builtin___int)
    type___TargetingDimensionValue = TargetingDimensionValue
    TargetingDimension: _TargetingDimension
    class _TargetingDimension(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            TargetingDimensionEnum.TargetingDimensionValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 0)
        UNKNOWN = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 1)
        KEYWORD = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 2)
        AUDIENCE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 3)
        TOPIC = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 4)
        GENDER = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 5)
        AGE_RANGE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 6)
        PLACEMENT = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 7)
        PARENTAL_STATUS = typing___cast(
            TargetingDimensionEnum.TargetingDimensionValue, 8
        )
        INCOME_RANGE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 9)
    UNSPECIFIED = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 0)
    UNKNOWN = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 1)
    KEYWORD = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 2)
    AUDIENCE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 3)
    TOPIC = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 4)
    GENDER = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 5)
    AGE_RANGE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 6)
    PLACEMENT = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 7)
    PARENTAL_STATUS = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 8)
    INCOME_RANGE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 9)
    type___TargetingDimension = TargetingDimension
    def __init__(self,) -> None: ...

type___TargetingDimensionEnum = TargetingDimensionEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.tracking_code_page_format_pb2 import (
    TrackingCodePageFormatEnum as google___ads___googleads___v6___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum,
)
from google.ads.google_ads.v6.proto.enums.tracking_code_type_pb2 import (
    TrackingCodeTypeEnum as google___ads___googleads___v6___enums___tracking_code_type_pb2___TrackingCodeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TagSnippet(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v6___enums___tracking_code_type_pb2___TrackingCodeTypeEnum.TrackingCodeTypeValue = ...
    page_format: google___ads___googleads___v6___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum.TrackingCodePageFormatValue = ...
    global_site_tag: typing___Text = ...
    event_snippet: typing___Text = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v6___enums___tracking_code_type_pb2___TrackingCodeTypeEnum.TrackingCodeTypeValue
        ] = None,
        page_format: typing___Optional[
            google___ads___googleads___v6___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum.TrackingCodePageFormatValue
        ] = None,
        global_site_tag: typing___Optional[typing___Text] = None,
        event_snippet: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_event_snippet",
            b"_event_snippet",
            "_global_site_tag",
            b"_global_site_tag",
            "event_snippet",
            b"event_snippet",
            "global_site_tag",
            b"global_site_tag",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_event_snippet",
            b"_event_snippet",
            "_global_site_tag",
            b"_global_site_tag",
            "event_snippet",
            b"event_snippet",
            "global_site_tag",
            b"global_site_tag",
            "page_format",
            b"page_format",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_event_snippet", b"_event_snippet"],
    ) -> typing_extensions___Literal["event_snippet"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_global_site_tag", b"_global_site_tag"
        ],
    ) -> typing_extensions___Literal["global_site_tag"]: ...

type___TagSnippet = TagSnippet



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2 import (
    KeywordPlanNetworkEnum as google___ads___googleads___v4___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanCampaign(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    keyword_plan_network: google___ads___googleads___v4___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum.KeywordPlanNetworkValue = ...
    @property
    def keyword_plan(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def language_constants(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def geo_targets(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanGeoTarget
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        keyword_plan: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        language_constants: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        keyword_plan_network: typing___Optional[
            google___ads___googleads___v4___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum.KeywordPlanNetworkValue
        ] = None,
        cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        geo_targets: typing___Optional[
            typing___Iterable[type___KeywordPlanGeoTarget]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "id",
            b"id",
            "keyword_plan",
            b"keyword_plan",
            "name",
            b"name",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "geo_targets",
            b"geo_targets",
            "id",
            b"id",
            "keyword_plan",
            b"keyword_plan",
            "keyword_plan_network",
            b"keyword_plan_network",
            "language_constants",
            b"language_constants",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

type___KeywordPlanCampaign = KeywordPlanCampaign

class KeywordPlanGeoTarget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def geo_target_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        geo_target_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "geo_target_constant", b"geo_target_constant"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "geo_target_constant", b"geo_target_constant"
        ],
    ) -> None: ...

type___KeywordPlanGeoTarget = KeywordPlanGeoTarget



from typing import Any

class DetailPlacementViewServiceStub:
    GetDetailPlacementView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DetailPlacementViewServiceServicer:
    def GetDetailPlacementView(self, request: Any, context: Any) -> None: ...

def add_DetailPlacementViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Video(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: typing___Text = ...
    channel_id: typing___Text = ...
    duration_millis: builtin___int = ...
    title: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[typing___Text] = None,
        channel_id: typing___Optional[typing___Text] = None,
        duration_millis: typing___Optional[builtin___int] = None,
        title: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_channel_id",
            b"_channel_id",
            "_duration_millis",
            b"_duration_millis",
            "_id",
            b"_id",
            "_title",
            b"_title",
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "title",
            b"title",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_channel_id",
            b"_channel_id",
            "_duration_millis",
            b"_duration_millis",
            "_id",
            b"_id",
            "_title",
            b"_title",
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "resource_name",
            b"resource_name",
            "title",
            b"title",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_channel_id", b"_channel_id"]
    ) -> typing_extensions___Literal["channel_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_duration_millis", b"_duration_millis"
        ],
    ) -> typing_extensions___Literal["duration_millis"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_title", b"_title"]
    ) -> typing_extensions___Literal["title"]: ...

type___Video = Video



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AppPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AppPlaceholderFieldValue = typing___NewType(
        "AppPlaceholderFieldValue", builtin___int
    )
    type___AppPlaceholderFieldValue = AppPlaceholderFieldValue
    AppPlaceholderField: _AppPlaceholderField
    class _AppPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AppPlaceholderFieldEnum.AppPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 0)
        UNKNOWN = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 1)
        STORE = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 2)
        ID = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 3)
        LINK_TEXT = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 4)
        URL = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 5)
        FINAL_URLS = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 6)
        FINAL_MOBILE_URLS = typing___cast(
            AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 7
        )
        TRACKING_URL = typing___cast(
            AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 8
        )
        FINAL_URL_SUFFIX = typing___cast(
            AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 9
        )
    UNSPECIFIED = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 1)
    STORE = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 2)
    ID = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 3)
    LINK_TEXT = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 4)
    URL = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 5)
    FINAL_URLS = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 6)
    FINAL_MOBILE_URLS = typing___cast(
        AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 7
    )
    TRACKING_URL = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 8)
    FINAL_URL_SUFFIX = typing___cast(
        AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 9
    )
    type___AppPlaceholderField = AppPlaceholderField
    def __init__(self,) -> None: ...

type___AppPlaceholderFieldEnum = AppPlaceholderFieldEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserListAccessStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserListAccessStatusValue = typing___NewType(
        "UserListAccessStatusValue", builtin___int
    )
    type___UserListAccessStatusValue = UserListAccessStatusValue
    UserListAccessStatus: _UserListAccessStatus
    class _UserListAccessStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserListAccessStatusEnum.UserListAccessStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            UserListAccessStatusEnum.UserListAccessStatusValue, 0
        )
        UNKNOWN = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 1)
        ENABLED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 2)
        DISABLED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 3)
    UNSPECIFIED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 0)
    UNKNOWN = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 1)
    ENABLED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 2)
    DISABLED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 3)
    type___UserListAccessStatus = UserListAccessStatus
    def __init__(self,) -> None: ...

type___UserListAccessStatusEnum = UserListAccessStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DynamicSearchAdsSearchTermView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    search_term: typing___Text = ...
    headline: typing___Text = ...
    landing_page: typing___Text = ...
    page_url: typing___Text = ...
    has_negative_keyword: builtin___bool = ...
    has_matching_keyword: builtin___bool = ...
    has_negative_url: builtin___bool = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        search_term: typing___Optional[typing___Text] = None,
        headline: typing___Optional[typing___Text] = None,
        landing_page: typing___Optional[typing___Text] = None,
        page_url: typing___Optional[typing___Text] = None,
        has_negative_keyword: typing___Optional[builtin___bool] = None,
        has_matching_keyword: typing___Optional[builtin___bool] = None,
        has_negative_url: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_has_matching_keyword",
            b"_has_matching_keyword",
            "_has_negative_keyword",
            b"_has_negative_keyword",
            "_has_negative_url",
            b"_has_negative_url",
            "_headline",
            b"_headline",
            "_landing_page",
            b"_landing_page",
            "_page_url",
            b"_page_url",
            "_search_term",
            b"_search_term",
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "search_term",
            b"search_term",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_has_matching_keyword",
            b"_has_matching_keyword",
            "_has_negative_keyword",
            b"_has_negative_keyword",
            "_has_negative_url",
            b"_has_negative_url",
            "_headline",
            b"_headline",
            "_landing_page",
            b"_landing_page",
            "_page_url",
            b"_page_url",
            "_search_term",
            b"_search_term",
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "resource_name",
            b"resource_name",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_has_matching_keyword", b"_has_matching_keyword"
        ],
    ) -> typing_extensions___Literal["has_matching_keyword"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_has_negative_keyword", b"_has_negative_keyword"
        ],
    ) -> typing_extensions___Literal["has_negative_keyword"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_has_negative_url", b"_has_negative_url"
        ],
    ) -> typing_extensions___Literal["has_negative_url"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_headline", b"_headline"]
    ) -> typing_extensions___Literal["headline"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_landing_page", b"_landing_page"],
    ) -> typing_extensions___Literal["landing_page"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_page_url", b"_page_url"]
    ) -> typing_extensions___Literal["page_url"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_search_term", b"_search_term"]
    ) -> typing_extensions___Literal["search_term"]: ...

type___DynamicSearchAdsSearchTermView = DynamicSearchAdsSearchTermView
